@@ -251,12 +251,14 @@ class Player(game.ChessPlayer):
         
         # Catch if the child dies
         def cDied(sig, stackFrame):
-            os.wait()
+            try:
+                os.waitpid(-1, os.WNOHANG)
+            except OSError:
+                pass
         signal.signal(signal.SIGCHLD, cDied)
 
         # Fork off a child process to manage the engine
-        self.__pid = os.fork()
-        if self.__pid == 0:
+        if os.fork() == 0:
             # ..
             os.close(toManagerPipe[1])
             os.close(fromManagerPipe[0])
@@ -296,7 +298,10 @@ class Player(game.ChessPlayer):
                 
             # Catch if the child dies
             def childDied(sig, stackFrame):
-                os.wait()
+                try:
+                    os.waitpid(-1, os.WNOHANG)
+                except OSError:
+                    return
                 
                 # Close connection to the application
                 os.close(fromManagerPipe[1])
@@ -316,7 +321,7 @@ class Player(game.ChessPlayer):
                     
                     # One of the connections has closed - kill the engine and quit
                     if len(data) == 0:
-                        os.kill(self.__pid, signal.SIGQUIT)
+                        os.kill(engineFd, signal.SIGQUIT)
                         os._exit(0)
                     
                     # Send data from the application to the engines stdin
@@ -371,13 +376,17 @@ class Player(game.ChessPlayer):
         """Read an process data from the engine.
         
         This is non-blocking.
-        """
+        """       
         while True:
+            # Connection was closed
+            if self.__fromEngineFd == None:
+                return False
+
             # Check if data is available
             (rlist, _, _) = select.select([self.__fromEngineFd], [], [], 0)
             if len(rlist) == 0:
                 return True
-            
+
             # Read a chunk and process
             try:
                 data = os.read(self.__fromEngineFd, 256)
@@ -394,6 +403,9 @@ class Player(game.ChessPlayer):
     def sendToEngine(self, data):
         """
         """
+        if self.__toEngineFd == None:
+            return
+        
         try:
             os.write(self.__toEngineFd, data)
         except OSError, e:
@@ -403,6 +415,7 @@ class Player(game.ChessPlayer):
         """Disconnect the AI"""
         fd = self.__toEngineFd
         self.__toEngineFd = None
+        self.__fromEngineFd = None
         
         # Send quit
         try:
