@@ -4,7 +4,7 @@ import os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR    = os.path.join('/usr/local', 'share') 
+APP_DATA_DIR    = os.path.join('/gnome/usr', 'share') 
 ICON_DIR        = os.path.join(APP_DATA_DIR, 'pixmaps')
 TEXTURE_DIR     = os.path.join(ICON_DIR, 'glchess')
 GLADE_DIR       = os.path.join(APP_DATA_DIR, 'glchess')
@@ -25,7 +25,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.20.0"
+VERSION   = "2.20.0.1"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
